"Example using nmlparser"

# This example:
#
# Defines classes in python.
# Defines corresponding classes as XML schema file.
# Writes out object tree as XML using generic "serializeObject" method
# Reads in object tree from XML using generic "parseXMLFile" method
#

from nmlparser import *
from nmlparser import schemaPkg


#
# Python class definitions for the objects to read/write to XML.
#
class Network:    
    def __init__(self):
        self.states = {} 
        self.connections = []
    def addState(self, s):
        self.states[s.name]=s
    
class State:
    def __init__(self, n=None, c=0):
        self.name = n
        self.count = c
    
class Connection:
    def __init__(self, s1=None, s2=None, w=0.0):
        self.s1 = s1
        self.s2 = s2
        self.w = w


print "Building an Network object tree in memory..."
net = Network()
net.addState(State("s1", 100))
net.addState(State("s2", 100))
net.addState(State("s3", 100))
net.addState(State("s4", 100))
net.connections.append(Connection("s1", "s2", 0.5))
net.connections.append(Connection("s3", "s2", 0.5))
net.connections.append(Connection("s2", "s3", 0.5))
net.connections.append(Connection("s4", "s2", 0.5))


print "Reading the test-net.sch schema file"
netSchema = parseSchemaFile("test-net.sch")

#
# Serializing an object tree out to XML....
#
print "Printing the in memory network using serializeObject()"
print serializeObject(net, netSchema)


# --- geek notes ---
# Code generation in java / python from schema
#
# javagen(netSchema)
# javagen(schemaPkg)
# pygen(netSchema)
# pygen(schemaPkg)
#
# Note we can also use the serializeObject() method
# to serialize an in memory schema - by passing it
# the schema of schema (schemaPkg)
# print serializeObject(netSchema, schemaPkg)
#


# Reading an XML file into an object tree
print "Reading in test-net.xml:"
tree = parseXMLFile("test-net.xml", locals(), netSchema)

print "Displaying object as XML using serializeObject()"
print serializeObject(tree, netSchema)
